@@ -1,9 +1,9 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-01-08 23:54:55 mtw>
+# Last changed Time-stamp: <2015-01-26 09:33:55 mtw>
 
 package Bio::ViennaNGS;
 
-use version; our $VERSION = qv('0.12_09');
+use version; our $VERSION = qv('0.12_11');
 
 1;
 
@@ -28,12 +28,21 @@ The main Bio::ViennaNGS module is shipped with a complementary set of
 =item L<Bio::ViennaNGS::AnnoC>: A Moose interface for storage and
 conversion of sequence annotation data.
 
+=item L<Bio::ViennaNGS::Bam>: Routines for high-level manipulation of
+BAM files.
+
 =item L<Bio::ViennaNGS::BamStat>: A L<Moose> based class for
 collecting mapping statistics.
 
 =item L<Bio::ViennaNGS::BamStatSummary>: A L<Moose> interface for
 processing L<Bio::ViennaNGS::BamStat> objects on a set of BAM files.
 
+=item L<Bio::ViennaNGS::Bed>: A L<Moose> interface for manipulation of
+genomic interval data in BED format.
+
+=item L<Bio::ViennaNGS::Expression>: An object oriented interface for
+read-count based gene expression analysis.
+
 =item L<Bio::ViennaNGS::Fasta>: Routines for accessing genomic
 sequences implemented through a L<Moose> interface to
 L<Bio::DB::Fasta>.
@@ -145,7 +154,7 @@ Fastq file by user defined length.
 The L<Bio::ViennaNGS> modules and classes depend on a set of Perl
 modules, some of which are part of the Perl core distribution:
 
-=over 16
+=over 17
 
 =item L<Bio::Perl> >= 1.00690001
 
@@ -177,6 +186,8 @@ modules, some of which are part of the Perl core distribution:
 
 =item L<MooseX::Clone>
 
+=item L<MooseX::InstanceTracking>
+
 =item L<Tie::Hash::Indexed>
 
 =back
@@ -233,7 +244,7 @@ test Windows compatibility.
 
 =head1 SEE ALSO
 
-=over 13
+=over 14
 
 =item L<Bio::ViennaNGS::AnnoC>
 
@@ -243,6 +254,10 @@ test Windows compatibility.
 
 =item L<Bio::ViennaNGS::BamStatSummary>
 
+=item L<Bio::ViennaNGS::Bed>
+
+=item L<Bio::ViennaNGS::Expression>
+
 =item L<Bio::ViennaNGS::Fasta>
 
 =item L<Bio::ViennaNGS::Feature>
@@ -253,10 +268,10 @@ test Windows compatibility.
 
 =item L<Bio::ViennaNGS::SpliceJunc>
 
-=item L<Bio::ViennaNGS::Util>
-
 =item L<Bio::ViennaNGS::Tutorial>
 
+=item L<Bio::ViennaNGS::Util>
+
 =item L<Bio::ViennaNGS::UCSC>
 
 =item L<Bio::ViennaNGS::Util>
@@ -279,7 +294,8 @@ test Windows compatibility.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
+Copyright (C) 2014-2015 Michael T. Wolfinger
+E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.12.4 or,
